==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/backend/mail/replica/api/IDbMailboxRecordsAsync.java <==
package net.bluemind.backend.mail.replica.api;
import net.bluemind.core.api.AsyncHandler;
import net.bluemind.core.api.BMAsyncApi;

@BMAsyncApi(net.bluemind.backend.mail.replica.api.IDbMailboxRecords.class)
public interface IDbMailboxRecordsAsync  {

	void getVersion(
	               AsyncHandler<Long> handler);

	void filteredChangesetById(java.lang.Long since , net.bluemind.core.container.model.ItemFlagFilter arg1 , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<net.bluemind.core.container.model.ItemVersion>> handler);

	void itemChangelog(java.lang.String uid , java.lang.Long arg1 , 
	               AsyncHandler<net.bluemind.core.container.model.ItemChangelog> handler);

	void changeset(java.lang.Long since , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<java.lang.String>> handler);

	void changesetById(java.lang.Long since , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<java.lang.Long>> handler);

	void containerChangelog(java.lang.Long arg0 , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangelog> handler);

	void allIds(java.lang.String filter , java.lang.Long knownContainerVersion , java.lang.Integer limit , java.lang.Integer offset , 
	               AsyncHandler<net.bluemind.core.api.ListResult<java.lang.Long>> handler);

	void count(net.bluemind.core.container.model.ItemFlagFilter arg0 , 
	               AsyncHandler<net.bluemind.core.container.api.Count> handler);

	void sortedIds(net.bluemind.core.container.model.SortDescriptor arg0 , 
	               AsyncHandler<java.util.List<java.lang.Long>> handler);

	void multipleGetById(java.util.List<java.lang.Long> arg0 , 
	               AsyncHandler<java.util.List<net.bluemind.core.container.model.ItemValue<net.bluemind.backend.mail.replica.api.MailboxRecord>>> handler);

	void getCompleteById(long id , 
	               AsyncHandler<net.bluemind.core.container.model.ItemValue<net.bluemind.backend.mail.replica.api.MailboxRecord>> handler);

	void update(java.lang.String uid , net.bluemind.backend.mail.replica.api.MailboxRecord mail , 
	               AsyncHandler<Void> handler);

	void updates(java.util.List<net.bluemind.backend.mail.replica.api.MailboxRecord> records , 
	               AsyncHandler<Void> handler);

	void delete(java.lang.String uid , 
	               AsyncHandler<Void> handler);

	void create(java.lang.String uid , net.bluemind.backend.mail.replica.api.MailboxRecord mail , 
	               AsyncHandler<Void> handler);

	void havingBodyVersionLowerThan(int version , 
	               AsyncHandler<java.util.List<net.bluemind.backend.mail.replica.api.ImapBinding>> handler);

	void all(
	               AsyncHandler<java.util.List<net.bluemind.core.container.model.ItemValue<net.bluemind.backend.mail.replica.api.MailboxRecord>>> handler);

	void getCompleteByImapUid(long imapUid , 
	               AsyncHandler<net.bluemind.core.container.model.ItemValue<net.bluemind.backend.mail.replica.api.MailboxRecord>> handler);

	void imapBindings(java.util.List<java.lang.Long> ids , 
	               AsyncHandler<java.util.List<net.bluemind.backend.mail.replica.api.ImapBinding>> handler);

	void deleteAll(
	               AsyncHandler<Void> handler);

	void fetchComplete(long imapUid , 
	               AsyncHandler<net.bluemind.core.api.Stream> handler);

	void getComplete(java.lang.String uid , 
	               AsyncHandler<net.bluemind.core.container.model.ItemValue<net.bluemind.backend.mail.replica.api.MailboxRecord>> handler);

	void prepareContainerDelete(
	               AsyncHandler<Void> handler);

	void deleteImapUids(java.util.List<java.lang.Long> uids , 
	               AsyncHandler<Void> handler);

}

==> net.bluemind.p2.platform-5.5.3112.zip: net/bluemind/backend/mail/replica/api/IDbMailboxRecordsAsync.java <==
package net.bluemind.backend.mail.replica.api;
import net.bluemind.core.api.AsyncHandler;
import net.bluemind.core.api.BMAsyncApi;

@BMAsyncApi(net.bluemind.backend.mail.replica.api.IDbMailboxRecords.class)
public interface IDbMailboxRecordsAsync  {

	void all(
	               AsyncHandler<java.util.List<net.bluemind.core.container.model.ItemValue<net.bluemind.backend.mail.replica.api.MailboxRecord>>> handler);

	void allIds(
	               AsyncHandler<java.util.List<java.lang.Long>> handler);

	void changeset(java.lang.Long since , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<java.lang.String>> handler);

	void changesetById(java.lang.Long since , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<java.lang.Long>> handler);

	void count(net.bluemind.core.container.model.ItemFlagFilter arg0 , 
	               AsyncHandler<net.bluemind.core.container.api.Count> handler);

	void create(java.lang.String uid , net.bluemind.backend.mail.replica.api.MailboxRecord mail , 
	               AsyncHandler<net.bluemind.core.container.model.ItemVersion> handler);

	void createById(long id , net.bluemind.backend.mail.replica.api.MailboxRecord mail , 
	               AsyncHandler<net.bluemind.core.container.api.Ack> handler);

	void delete(java.lang.String uid , 
	               AsyncHandler<Void> handler);

	void deleteAll(
	               AsyncHandler<Void> handler);

	void deleteById(long id , 
	               AsyncHandler<Void> handler);

	void deleteImapUids(java.util.List<java.lang.Long> uids , 
	               AsyncHandler<Void> handler);

	void fetchComplete(long imapUid , 
	               AsyncHandler<net.bluemind.core.api.Stream> handler);

	void fetchCompleteByGuid(java.lang.String guid , 
	               AsyncHandler<net.bluemind.core.api.Stream> handler);

	void filteredChangesetById(java.lang.Long since , net.bluemind.core.container.model.ItemFlagFilter arg1 , 
	               AsyncHandler<net.bluemind.core.container.model.ContainerChangeset<net.bluemind.core.container.model.ItemVersion>> handler);

	void getComplete(java.lang.String uid , 
	               AsyncHandler<net.bluemind.core.container.model.ItemValue<net.bluemind.backend.mail.replica.api.MailboxRecord>> handler);

	void getCompleteById(long id , 
	               AsyncHandler<net.bluemind.core.container.model.ItemValue<net.bluemind.backend.mail.replica.api.MailboxRecord>> handler);

	void getCompleteByImapUid(long imapUid , 
	               AsyncHandler<net.bluemind.core.container.model.ItemValue<net.bluemind.backend.mail.replica.api.MailboxRecord>> handler);

	void getVersion(
	               AsyncHandler<Long> handler);

	void havingBodyVersionLowerThan(int version , 
	               AsyncHandler<java.util.List<net.bluemind.backend.mail.replica.api.ImapBinding>> handler);

	void imapBindings(java.util.List<java.lang.Long> ids , 
	               AsyncHandler<java.util.List<net.bluemind.backend.mail.replica.api.ImapBinding>> handler);

	void imapIdSet(java.lang.String set , java.lang.String filter , 
	               AsyncHandler<java.util.List<net.bluemind.backend.mail.replica.api.RawImapBinding>> handler);

	void itemChangelog(java.lang.String uid , java.lang.Long arg1 , 
	               AsyncHandler<net.bluemind.core.container.model.ItemChangelog> handler);

	void labels(
	               AsyncHandler<java.util.List<java.lang.String>> handler);

	void lightSlice(java.util.List<java.lang.Long> ids , 
	               AsyncHandler<java.util.List<net.bluemind.backend.mail.replica.api.WithId<net.bluemind.backend.mail.replica.api.MailboxRecord>>> handler);

	void multiCreate(java.util.List<net.bluemind.backend.mail.replica.api.MailboxRecord> mails , 
	               AsyncHandler<java.util.List<net.bluemind.core.container.model.ItemIdentifier>> handler);

	void multipleGetById(java.util.List<java.lang.Long> arg0 , 
	               AsyncHandler<java.util.List<net.bluemind.core.container.model.ItemValue<net.bluemind.backend.mail.replica.api.MailboxRecord>>> handler);

	void prepareContainerDelete(
	               AsyncHandler<Void> handler);

	void slice(java.util.List<java.lang.Long> ids , 
	               AsyncHandler<java.util.List<net.bluemind.backend.mail.replica.api.WithId<net.bluemind.backend.mail.replica.api.MailboxRecord>>> handler);

	void sortedIds(net.bluemind.core.container.model.SortDescriptor arg0 , 
	               AsyncHandler<java.util.List<java.lang.Long>> handler);

	void sortedUids(net.bluemind.core.container.model.SortDescriptor arg0 , 
	               AsyncHandler<java.util.List<java.lang.String>> handler);

	void update(java.lang.String uid , net.bluemind.backend.mail.replica.api.MailboxRecord mail , 
	               AsyncHandler<Void> handler);

	void updateById(long id , net.bluemind.backend.mail.replica.api.MailboxRecord value , 
	               AsyncHandler<net.bluemind.core.container.api.Ack> handler);

	void updates(java.util.List<net.bluemind.backend.mail.replica.api.MailboxRecord> records , 
	               AsyncHandler<net.bluemind.core.container.api.Ack> handler);

	void weight(
	               AsyncHandler<net.bluemind.backend.mail.replica.api.Weight> handler);

}
